@@ -319,40 +319,6 @@ adwaita_engine_render_extension (GtkThemingEngine *engine,
      gap_side);
 }
 
-static void
-adwaita_engine_render_frame (GtkThemingEngine *engine,
-                             cairo_t          *cr,
-                             gdouble           x,
-                             gdouble           y,
-                             gdouble           width,
-                             gdouble           height)
-{
-  adwaita_trim_allocation_for_scale (engine,
-                                     &x, &y,
-                                     &width, &height);
-
-  GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_frame
-    (engine, cr, x, y,
-     width, height);
-}
-
-static void
-adwaita_engine_render_background (GtkThemingEngine *engine,
-                                  cairo_t          *cr,
-                                  gdouble           x,
-                                  gdouble           y,
-                                  gdouble           width,
-                                  gdouble           height)
-{
-  adwaita_trim_allocation_for_scale (engine,
-                                     &x, &y,
-                                     &width, &height);
-
-  GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_background
-    (engine, cr, x, y,
-     width, height);
-}
-
 static void
 adwaita_engine_render_expander (GtkThemingEngine *engine,
                                 cairo_t          *cr,
@@ -434,172 +400,6 @@ adwaita_engine_render_expander (GtkThemingEngine *engine,
   cairo_restore (cr);
 }
 
-static void
-adwaita_engine_render_activity (GtkThemingEngine *engine,
-                                cairo_t          *cr,
-                                gdouble           x,
-                                gdouble           y,
-                                gdouble           width,
-                                gdouble           height)
-{
-  GtkStateFlags state;
-
-  cairo_save (cr);
-  state = gtk_theming_engine_get_state (engine);
-
-  adwaita_trim_allocation_for_scale (engine,
-                                     &x, &y,
-                                     &width, &height);
-
-  GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_activity
-    (engine, cr,
-     x, y, width, height);
-
-  if (gtk_theming_engine_has_class (engine, GTK_STYLE_CLASS_PROGRESSBAR))
-    {
-      cairo_pattern_t *pattern = NULL;
-
-      gtk_theming_engine_get (engine, state,
-                              "-adwaita-progressbar-pattern", &pattern,
-                              NULL);
-
-      if (pattern != NULL)
-        {
-          cairo_pattern_set_extend (pattern, CAIRO_EXTEND_REPEAT);
-          cairo_scale (cr, 20, 20);
-          cairo_set_source (cr, pattern);
-          cairo_scale (cr, 1.0 / 20, 1.0 / 20);
-
-          cairo_rectangle (cr, x, y, width, height);
-          cairo_fill (cr);
-
-          cairo_pattern_destroy (pattern);
-        }
-    }
-
-  cairo_restore (cr);
-}
-
-static void
-render_switch_lines (GtkThemingEngine *engine,
-                     cairo_t *cr,
-                     gdouble x,
-                     gdouble y,
-                     gdouble width,
-                     gdouble height,
-                     GtkOrientation orientation)
-{
-  GtkStateFlags state;
-  GdkRGBA lines_color;
-
-  state = gtk_theming_engine_get_state (engine);
-
-  if (state & GTK_STATE_FLAG_INSENSITIVE)
-    return;
-
-  gtk_theming_engine_get_color (engine, state, &lines_color);
-
-  cairo_save (cr);
-
-  cairo_translate (cr,
-                   x + width / 2.0 - 4.0,
-                   y + height / 2.0 - 3.0);
-
-  cairo_move_to (cr, 0.0, 0.0);
-  cairo_set_line_width (cr, 2.0);
-  cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
-
-  cairo_line_to (cr, 0.0, 6.0);
-  cairo_move_to (cr, 4.0, 0.0);
-  cairo_line_to (cr, 4.0, 6.0);
-  cairo_move_to (cr, 8.0, 0.0);
-  cairo_line_to (cr, 8.0, 6.0);
-
-  gdk_cairo_set_source_rgba (cr, &lines_color);
-  cairo_stroke (cr);
-
-  cairo_restore (cr);
-}
-
-static void
-adwaita_engine_render_slider (GtkThemingEngine *engine,
-                              cairo_t          *cr,
-                              gdouble           x,
-                              gdouble           y,
-                              gdouble           width,
-                              gdouble           height,
-                              GtkOrientation    orientation)
-{
-  const GtkWidgetPath *path;
-
-  GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_slider
-    (engine, cr,
-     x, y, width, height,
-     orientation);
-
-  path = gtk_theming_engine_get_path (engine);
-
-  if (gtk_widget_path_is_type (path, GTK_TYPE_SWITCH))
-    render_switch_lines (engine, cr, x, y, width, height, orientation);
-}
-
-static void
-adwaita_engine_render_handle (GtkThemingEngine *engine,
-                              cairo_t          *cr,
-                              gdouble           x,
-                              gdouble           y,
-                              gdouble           width,
-                              gdouble           height)
-{
-  if (gtk_theming_engine_has_class (engine, GTK_STYLE_CLASS_PANE_SEPARATOR))
-    {
-      GdkRGBA fg;
-      GtkStateFlags state;
-      gdouble xx, yy;
-
-      state = gtk_theming_engine_get_state (engine);
-      gtk_theming_engine_get_color (engine, state, &fg);
-
-      GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_background
-        (engine, cr, x, y, width, height);
-      GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_frame
-        (engine, cr, x, y, width, height);
-
-      cairo_save (cr);
-      cairo_set_line_width (cr, 2.0);
-      gdk_cairo_set_source_rgba (cr, &fg);
-
-      if (width > height)
-        {
-          for (xx = x + width / 2 - 12; xx <= x + width / 2 + 12; xx += 6)
-            {
-              cairo_arc (cr, xx, y + height / 2.0,
-                         1.0,
-                         0, G_PI * 2.0);
-              cairo_fill (cr);
-            }
-        }
-      else
-        {
-          for (yy = y + height / 2 - 12; yy <= y + height / 2 + 12; yy += 6)
-            {
-              cairo_arc (cr, x + width / 2.0, yy,
-                         1.0,
-                         0, G_PI * 2.0);
-              cairo_fill (cr);
-            }
-        }
-
-      cairo_restore (cr);
-    }
-  else
-    {
-      GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_handle
-        (engine, cr,
-         x, y, width, height);
-    }
-}
-
 static void
 adwaita_engine_class_init (AdwaitaEngineClass *klass)
 {
@@ -608,12 +408,7 @@ adwaita_engine_class_init (AdwaitaEngineClass *klass)
   engine_class->render_arrow = adwaita_engine_render_arrow;
   engine_class->render_focus = adwaita_engine_render_focus;
   engine_class->render_extension = adwaita_engine_render_extension;
-  engine_class->render_frame = adwaita_engine_render_frame;
-  engine_class->render_background = adwaita_engine_render_background;
   engine_class->render_expander = adwaita_engine_render_expander;
-  engine_class->render_activity = adwaita_engine_render_activity;
-  engine_class->render_slider = adwaita_engine_render_slider;
-  engine_class->render_handle = adwaita_engine_render_handle;
 
   gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
                                         g_param_spec_boxed ("focus-border-color",
@@ -636,11 +431,6 @@ adwaita_engine_class_init (AdwaitaEngineClass *klass)
                                                               "Focus border uses dashes",
                                                               "Focus border uses dashes",
                                                               FALSE, 0));
-  gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
-                                        g_param_spec_boxed ("progressbar-pattern",
-                                                            "Progressbar pattern",
-                                                            "Progressbar pattern",
-                                                            CAIRO_GOBJECT_TYPE_PATTERN, 0));
 }
 
 static void
